@@ -104,9 +104,7 @@ def make_sweep(hmodel: HubitModel, nproc: Any = None) -> None:
         ]
     )
     for inp, response in zip(inps, responses):
-        values = [
-            getitem(inp, HubitModelPath.as_internal(ipath)) for ipath in input_paths
-        ]
+        values = [getitem(inp, ipath) for ipath in input_paths]
         values.extend([response[qpath] for qpath in query])
         lines.append(fstr.format(*values))
     lines.append(sepstr)
